sectional_bloc_builder library
Public exports for sectional BLoC building.
Classes
-
SectionalBlocBuilder<
B extends StateStreamable< S> , S extends SectionalState<T> , T extends Enum> - A wrapper for BlocBuilder that provides sectional building capabilities. Only rebuilds when the specified section and/or status changes.
-
SectionalState<
T extends Enum> - Abstract base class for states that support sectional UI building
-
UiSectionStatus<
T extends Enum> - Represents a sectional status with both UI section and request status information Used to identify which specific section(s) of the UI should be updated
Enums
- RequestStatus
- Common enum for request status across the application